A simple flask oauth2 provider
=======================

This project aims to be lightweight oauth2 provider for flask based
applications.

Functionality now is rather limited - just password grant authorization and
token refresh. The other parts of ouath2 process and some documentation are
comming soon. :)
